@@ -633,10 +633,10 @@ EOM
       yq -i ".cms_nfs.server=${filestore_ip}" ${PRODUCTSVAR_FILE}
       yq -i ".cms_nfs.path=${filestore_share}" ${PRODUCTSVAR_FILE}
 
-      echo "[INFO] Update NFS mountOptions [nfsvers=3.0]"
-      yq -i '.cms_nfs.mountOptions[0]="nfsvers=3.0"' ${PRODUCTSVAR_FILE}
-      yq -i '.cms_pvc.cmscontent.mountOptions[0]="nfsvers=3.0"' ${PRODUCTSVAR_FILE}
-      yq -i '.cms_pvc.backuprestore.mountOptions[0]="nfsvers=3.0"' ${PRODUCTSVAR_FILE}
+      echo "[INFO] Update NFS mountOptions [nfsvers=3]"
+      yq -i '.cms_nfs.mountOptions[0]="nfsvers=3"' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_pvc.cmscontent.mountOptions[0]="nfsvers=3"' ${PRODUCTSVAR_FILE}
+      yq -i '.cms_pvc.backuprestore.mountOptions[0]="nfsvers=3"' ${PRODUCTSVAR_FILE}
 
       if [[ -z "$IMAGE_REGISTRY" ]] && [[ -z "$GCP_GCR" ]]; then
         echo "[ERROR] Both image_registry and gcp_gcr are empty, make sure one of them has proper value provided in cms.var file."
